@@ -671,3 +671,201 @@ class Test(unittest.TestCase):
 		# Make sure desired SQL and parameters are created.
 		self.assertEqual(sql, dest_sql)
 		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_to_named_unescaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % :1
+
+		to::
+
+			SELECT 5 % :_1
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric', 'named')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % :1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 % :_1;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_to_named_dollar_unescaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % :1
+
+		to::
+
+			SELECT 5 % $_1
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric', 'named_dollar')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % :1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 % $_1;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_to_pyformat_escaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % :1
+
+		to::
+
+			SELECT 5 %% %(_1)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric', 'pyformat')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % :1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 %% %(_1)s;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_dollar_to_named_unescaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % $1
+
+		to::
+
+			SELECT 5 % :_1
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric_dollar', 'named')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % $1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 % :_1;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_dollar_to_named_dollar_unescaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % $1
+
+		to::
+
+			SELECT 5 % $_1
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric_dollar', 'named_dollar')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % $1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 % $_1;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
+
+	def test_5_numeric_dollar_to_pyformat_escaped_percent(self):
+		"""
+		Test converting from::
+
+			SELECT 5 % $1
+
+		to::
+
+			SELECT 5 %% %(_1)s
+		"""
+		# Create instance.
+		query = sqlparams.SQLParams('numeric_dollar', 'pyformat')
+
+		# Source SQL and params.
+		src_sql = """
+			SELECT 5 % $1;
+		"""
+		value = 2
+		src_params = [value]
+
+		# Desired SQL and params.
+		dest_sql = """
+			SELECT 5 %% %(_1)s;
+		"""
+		dest_params = {'_1': value}
+
+		# Format SQL with params.
+		sql, params = query.format(src_sql, src_params)
+
+		# Make sure desired SQL and parameters are created.
+		self.assertEqual(sql, dest_sql)
+		self.assertEqual(params, dest_params)
